==> windmill_api-1.46.2.tar.gz: windmill_api-1.46.2/windmill_api/models/get_flow_by_path_response_200_value_failure_module_sleep_type_1.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_1_type import (
    GetFlowByPathResponse200ValueFailureModuleSleepType1Type,
)

T = TypeVar("T", bound="GetFlowByPathResponse200ValueFailureModuleSleepType1")


@attr.s(auto_attribs=True)
class GetFlowByPathResponse200ValueFailureModuleSleepType1:
    """
    Attributes:
        expr (str):
        type (GetFlowByPathResponse200ValueFailureModuleSleepType1Type):
    """

    expr: str
    type: GetFlowByPathResponse200ValueFailureModuleSleepType1Type
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        expr = self.expr
        type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "expr": expr,
                "type": type,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        expr = d.pop("expr")

        type = GetFlowByPathResponse200ValueFailureModuleSleepType1Type(d.pop("type"))

        get_flow_by_path_response_200_value_failure_module_sleep_type_1 = cls(
            expr=expr,
            type=type,
        )

        get_flow_by_path_response_200_value_failure_module_sleep_type_1.additional_properties = d
        return get_flow_by_path_response_200_value_failure_module_sleep_type_1

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.224.1.tar.gz: windmill_api-1.224.1/windmill_api/models/get_flow_by_path_response_200_value_failure_module_sleep_type_1.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_1_type import (
    GetFlowByPathResponse200ValueFailureModuleSleepType1Type,
)

T = TypeVar("T", bound="GetFlowByPathResponse200ValueFailureModuleSleepType1")


@_attrs_define
class GetFlowByPathResponse200ValueFailureModuleSleepType1:
    """
    Attributes:
        expr (str):
        type (GetFlowByPathResponse200ValueFailureModuleSleepType1Type):
    """

    expr: str
    type: GetFlowByPathResponse200ValueFailureModuleSleepType1Type
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        expr = self.expr
        type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "expr": expr,
                "type": type,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        expr = d.pop("expr")

        type = GetFlowByPathResponse200ValueFailureModuleSleepType1Type(d.pop("type"))

        get_flow_by_path_response_200_value_failure_module_sleep_type_1 = cls(
            expr=expr,
            type=type,
        )

        get_flow_by_path_response_200_value_failure_module_sleep_type_1.additional_properties = d
        return get_flow_by_path_response_200_value_failure_module_sleep_type_1

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
